@@ -1,7 +1,13 @@
 //! Const-friendly decoding operations for [`UInt`]
 
+mod decoder;
+
+#[cfg(feature = "rlp")]
+mod rlp;
+
 use super::UInt;
-use crate::{limb, Encoding, Limb};
+use crate::{limb, Encoding};
+use decoder::Decoder;
 
 impl<const LIMBS: usize> UInt<LIMBS> {
     /// Create a new [`UInt`] from the provided big endian bytes.
@@ -119,61 +125,6 @@ impl<const LIMBS: usize> UInt<LIMBS> {
     }
 }
 
-#[derive(Clone, Debug)]
-struct Decoder<const LIMBS: usize> {
-    /// Limbs being decoded.
-    ///
-    /// Stored from least significant to most significant.
-    limbs: [Limb; LIMBS],
-
-    /// Current limb being decoded.
-    index: usize,
-
-    /// Total number of bytes consumed.
-    bytes: usize,
-}
-
-impl<const LIMBS: usize> Decoder<LIMBS> {
-    /// Create a new decoder.
-    pub const fn new() -> Self {
-        Self {
-            limbs: [Limb::ZERO; LIMBS],
-            index: 0,
-            bytes: 0,
-        }
-    }
-
-    /// Add a byte onto the [`UInt`] being decoded.
-    pub const fn add_byte(mut self, byte: u8) -> Self {
-        if self.bytes == limb::BYTE_SIZE {
-            const_assert!(self.index < LIMBS, "too many bytes in UInt");
-            self.index += 1;
-            self.bytes = 0;
-        }
-
-        self.limbs[self.index].0 |= (byte as limb::Inner) << (self.bytes * 8);
-        self.bytes += 1;
-        self
-    }
-
-    /// Finish decoding a [`UInt`], returning a decoded value only if we've
-    /// received the expected number of bytes.
-    pub const fn finish(self) -> UInt<LIMBS> {
-        const_assert!(self.index == LIMBS - 1, "decoded UInt is missing limbs");
-        const_assert!(
-            self.bytes == limb::BYTE_SIZE,
-            "decoded UInt is missing bytes"
-        );
-        UInt { limbs: self.limbs }
-    }
-}
-
-impl<const LIMBS: usize> Default for Decoder<LIMBS> {
-    fn default() -> Self {
-        Self::new()
-    }
-}
-
 /// Decode a single byte encoded as two hexadecimal characters.
 const fn decode_hex_byte(bytes: [u8; 2]) -> u8 {
     let mut i = 0;
